.. sphinx-mcp documentation master file, created by
   sphinx-quickstart on Sat Jul  5 21:22:54 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Overview
=========

``sphinx-mcp`` is a `Sphinx`_ documentation extension for Model Context Protocol (MCP) servers.
In this documentation, you will find information on how to install, configure, and use the extension to document MCP servers.
You will also find examples of how to use the extension with different MCP servers,
such as `pymcp`_ and `@modelcontextprotocol/server-everything`_.


.. toctree::
   :maxdepth: 2
   :caption: Contents

   usage
   example_pymcp/index
   example_everything/index

.. _Sphinx: https://www.sphinx-doc.org/
.. _pymcp: https://github.com/anirbanbasu/pymcp
.. _@modelcontextprotocol/server-everything: https://github.com/modelcontextprotocol/servers/tree/main/src/everything
